import _ from 'lodash';
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import ReactQuill from 'react-quill';

import ScoreIcon from 'riskofbias/robTable/components/ScoreIcon';
import SelectInput from 'shared/components/SelectInput';
import './ScoreForm.css';

class ScoreForm extends Component {
    constructor(props) {
        super(props);
        this.state = {
            scoreSymbols: {
                0: 'N/A',
                1: '--',
                2: '-',
                3: '+',
                4: '++',
                10: 'NR',
            },
            scoreShades: {
                0: '#E8E8E8',
                1: '#CC3333',
                2: '#FFCC00',
                3: '#6FFF00',
                4: '#00CC00',
                10: '#FFCC00',
            },
            scoreChoices: {
                0: 'Not applicable',
                1: 'Definitely high risk of bias',
                2: 'Probably high risk of bias',
                3: 'Probably low risk of bias',
                4: 'Definitely low risk of bias',
                10: 'Not reported',
            },
            score: null,
            notes: props.score.notes,
        };
        this.handleEditorInput = this.handleEditorInput.bind(this);
        this.selectScore = this.selectScore.bind(this);
    }

    componentWillMount() {
        this.selectScore(this.props.score.score);
    }

    componentWillUpdate(nextProps, nextState) {
        // update notes if addText is modified
        // (usually by copying notes over from another form)
        if (nextProps.addText !== this.props.addText) {
            this.setState({
                notes: this.state.notes + nextProps.addText,
            });
        }
        // if score notes is changed, change notes to new notes
        if (nextProps.score.notes !== this.props.score.notes) {
            this.setState({
                notes: nextProps.score.notes,
            });
        }
        // if score is changed, change to new score
        if (nextProps.score.score !== this.props.score.score) {
            this.selectScore(nextProps.score.score);
        }
    }

    selectScore(score) {
        this.setState({
            score,
            selectedShade: this.state.scoreShades[score],
            selectedSymbol: this.state.scoreSymbols[score],
        });
        this.validateInput(score, this.state.notes);
    }

    handleEditorInput(event) {
        this.setState({ notes: event });
        this.validateInput(this.state.score, event);
    }

    validateInput(score, notes) {
        if (this.state.notes.replace(/<\/?[^>]+(>|$)/g, '') == '' && score != 0) {
            this.props.updateNotesLeft(this.props.score.id, 'add');
        } else {
            this.props.updateNotesLeft(this.props.score.id, 'clear');
        }
    }

    render() {
        let { name } = this.props.score.metric,
            { scoreChoices, score, notes, selectedSymbol, selectedShade } = this.state,
            choices = _.map(scoreChoices, (v, k) => {
                return { id: parseInt(k), value: v };
            });

        return (
            <div className="score-form">
                <div>
                    <SelectInput
                        choices={choices}
                        id={name}
                        value={score}
                        handleSelect={this.selectScore}
                    />
                    <ScoreIcon shade={selectedShade} symbol={selectedSymbol} />
                </div>
                <ReactQuill
                    id={name}
                    value={notes}
                    onChange={this.handleEditorInput}
                    className="score-editor"
                />
            </div>
        );
    }
}

ScoreForm.propTypes = {
    score: PropTypes.shape({
        score: PropTypes.number.isRequired,
        notes: PropTypes.string.isRequired,
        metric: PropTypes.shape({
            name: PropTypes.string.isRequired,
        }).isRequired,
    }).isRequired,
    updateNotesLeft: PropTypes.func.isRequired,
};

export default ScoreForm;
